migrations

package
v0.0.6-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT, MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrCreateIndexesFailed = errors.New("create indexes failed")
	ErrDropIndexFailed     = errors.New("drop index failed")
)

Functions

This section is empty.

Types

type AddUserIndexesMigration

type AddUserIndexesMigration struct{}

AddUserIndexesMigration adds indexes to the users collection

func (*AddUserIndexesMigration) Description

func (m *AddUserIndexesMigration) Description() string

Description returns a human-readable description of what this migration does

func (*AddUserIndexesMigration) Down

Down rolls back the migration

func (*AddUserIndexesMigration) Up

Up executes the migration

func (*AddUserIndexesMigration) Version

func (m *AddUserIndexesMigration) Version() string

Version returns the unique version identifier for this migration

type CreateUsersCollectionMigration

type CreateUsersCollectionMigration struct{}

CreateUsersCollectionMigration creates the users collection

func (*CreateUsersCollectionMigration) Description

func (m *CreateUsersCollectionMigration) Description() string

Description returns a human-readable description of what this migration does

func (*CreateUsersCollectionMigration) Down

Down rolls back the migration

func (*CreateUsersCollectionMigration) Up

Up executes the migration

func (*CreateUsersCollectionMigration) Version

Version returns the unique version identifier for this migration

type Migration20251207_190640CreateProductCollection

type Migration20251207_190640CreateProductCollection struct{}

Migration20251207_190640CreateProductCollection create-product-collection

func (*Migration20251207_190640CreateProductCollection) Description

Description returns a human-readable description of what this migration does

func (*Migration20251207_190640CreateProductCollection) Down

Down rolls back the migration

func (*Migration20251207_190640CreateProductCollection) Up

Up executes the migration

func (*Migration20251207_190640CreateProductCollection) Version

Version returns the unique version identifier for this migration

type Migration20251207_192545TestDemoAgl

type Migration20251207_192545TestDemoAgl struct{}

Migration20251207_192545TestDemoAgl test-demo-agl

func (*Migration20251207_192545TestDemoAgl) Description

Description returns a human-readable description of what this migration does

func (*Migration20251207_192545TestDemoAgl) Down

Down rolls back the migration

func (*Migration20251207_192545TestDemoAgl) Up

Up executes the migration

func (*Migration20251207_192545TestDemoAgl) Version

Version returns the unique version identifier for this migration

type Migration_20251231_192427_add_user_indexes

type Migration_20251231_192427_add_user_indexes struct{}

Migration_20251231_192427_add_user_indexes add_user_indexes

func (*Migration_20251231_192427_add_user_indexes) Description

Description returns a human-readable description of what this migration does

func (*Migration_20251231_192427_add_user_indexes) Down

Down rolls back the migration

func (*Migration_20251231_192427_add_user_indexes) Up

Up executes the migration

func (*Migration_20251231_192427_add_user_indexes) Version

Version returns the unique version identifier for this migration

Jump to